kdiagram.plot.probabilistic.plot\_calibration\_sharpness
========================================================

.. currentmodule:: kdiagram.plot.probabilistic

.. autofunction:: plot_calibration_sharpness